"""Bot"""
import logging
import yaml

import slack
from playsound import playsound


class Bot:
    """Read the config file, subscribe to RTM events, parse messages and play sounds.

    Args:
        config (file): The config YAML file
    """

    def __init__(self, config):
        self._logger = self._get_logger()
        self._config = self._load_config(config)

        slack.RTMClient.run_on(event="message")(self._read_message)
        slack.RTMClient.run_on(event="hello")(self._hello)

    @staticmethod
    def _load_config(config):
        """Load the config"""
        return yaml.safe_load(config)

    @staticmethod
    def _get_logger():
        """Configure the logger"""
        logger = logging.getLogger(__name__)
        logger.setLevel(logging.INFO)

        logger_handler = logging.StreamHandler()
        logger_handler.setLevel(logging.INFO)

        formatter = logging.Formatter(
            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
        )
        logger_handler.setFormatter(formatter)
        logger.addHandler(logger_handler)

        return logger

    def _hello(self, **_payload):
        """Log if client connected successfully

        Args:
            **_payload (dict): Slack RTM payload
        """
        self._logger.info("client connected")

    def _read_message(self, **payload):
        """Read messages, extract trigger words and play sounds.

        Args:
            **payload (dict): Slack RTM payload
        """
        message_text = payload["data"].get("text", [])

        for trigger in self._config["triggers"]:
            if trigger["trigger"] in message_text:
                self._play_sound(trigger["sound"])

    def _play_sound(self, sound):
        """Play sounds from a mp3 or wav file.

        Args:
            sound (str): File path to a mp3 or wav file
        """
        self._logger.info("playing %s", sound)
        playsound(sound)



"""A Slack bot which plays sounds from the filesystem upon certain triggers. Install and configure
it on a RaspberryPi, connect some speakers and have fun.
"""
import os
import argparse

import slack

from .bot import Bot


def run():
    """Main method"""
    parser = argparse.ArgumentParser(description="Process some integers.")
    parser.add_argument(
        "--config", type=argparse.FileType("r"), help="path to the configuration file"
    )
    args = parser.parse_args()

    Bot(args.config)

    slack_token = os.environ["SLACK_API_TOKEN"]
    rtm_client = slack.RTMClient(token=slack_token)
    rtm_client.start()



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['audio_slackbot']

package_data = \
{'': ['*']}

install_requires = \
['playsound>=1.2,<2.0', 'pyyaml>=5.1,<6.0', 'slackclient==2.2.1']

entry_points = \
{'console_scripts': ['audio_slackbot = audio_slackbot:run']}

setup_kwargs = {
    'name': 'audio-slackbot',
    'version': '0.1.0',
    'description': 'A slack bot which plays sounds from the filesystem upon certain triggers.',
    'long_description': None,
    'author': 'Nikolai Gulatz',
    'author_email': 'nikolai.gulatz@posteo.de',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
